.. Sage documentation master file, created by sphinx-quickstart on Thu Aug 21 20:15:55 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

========================
Welcome to Sage Tutorial
========================

Sage is free, open-source math software that supports research and
teaching in algebra, geometry, number theory, cryptography,
numerical computation, and related areas. Both the Sage development
model and the technology in Sage itself are distinguished by an
extremely strong emphasis on openness, community, cooperation, and
collaboration: we are building the car, not reinventing the wheel.
The overall goal of Sage is to create a viable, free, open-source
alternative to Maple, Mathematica, Magma, and MATLAB.

This tutorial is the best way to become familiar with Sage in only
a few hours. You can read it in HTML or PDF versions, or from the
Sage notebook (click ``Help``, then click ``Tutorial`` to interactively
work through the tutorial from within Sage).

This work is licensed under a `Creative Commons Attribution-Share Alike
3.0 License`__.

__ http://creativecommons.org/licenses/by-sa/3.0/

.. toctree::
   :maxdepth: 2

   introduction
   tour
   interactive_shell
   interfaces
   latex
   programming
   sagetex
   afterword
   appendix
   bibliography

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
